@@ -8,7 +8,7 @@
 #' @param ... (any)\cr
 #'   The objects, which should be visible inside `.fn`.
 #' @param .parent (`environment`)\cr
-#'   Parent environment to look up names. Default so the global environment.
+#'   Parent environment to look up names. Default to [topenv()].
 #'
 #' @export
 #' @examples
@@ -24,7 +24,7 @@
 #' z = 300
 #' f = meta_f(1)
 #' f()
-crate = function(.fn, ..., .parent = .GlobalEnv) {
+crate = function(.fn, ..., .parent = topenv()) {
   nn = map_chr(substitute(list(...)), as.character)[-1L]
   environment(.fn) = list2env(setNames(list(...), nn), parent = .parent)
   .fn
