@@ -1,12 +1,13 @@
+#define R_NO_REMAP
 #include <R.h>
 #include <Rinternals.h>
 
 SEXP c_to_decimal(SEXP _bits) {
-    const R_len_t n = length(_bits);
+    const R_len_t n = Rf_length(_bits);
     const int * bits = LOGICAL(_bits);
 
     if (n > 30) {
-        error("to_decimal() only works for vectors with <= 30 elements");
+        Rf_error("to_decimal() only works for vectors with <= 30 elements");
     }
 
     int power = 1 << n;
@@ -16,7 +17,7 @@ SEXP c_to_decimal(SEXP _bits) {
         power >>= 1;
 
         if (bits[i] == NA_LOGICAL) {
-            error("Bit vector contains missing values");
+            Rf_error("Bit vector contains missing values");
         }
 
         if (bits[i]) {
@@ -24,5 +25,5 @@ SEXP c_to_decimal(SEXP _bits) {
         }
     }
 
-    return ScalarInteger(out);
+    return Rf_ScalarInteger(out);
 }
